<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct access forbidden.' );
}
/**
 * Filters and Actions
 */

/**
 * Enqueue Google fonts style to admin screen for custom header display.
 * @internal
 */
function _action_utouch_admin_fonts() {
	wp_enqueue_style( 'utouch-font', utouch_font_url(), array(), '1.0' );
}

add_action( 'admin_print_scripts-appearance_page_custom-header', '_action_utouch_admin_fonts' );


if ( ! function_exists( '_action_utouch_setup' ) ) : /**
 * Theme setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 * @internal
 */
	{

        function _action_utouch_setup() {

	        // Add support for editor styles.
	        add_theme_support( 'editor-styles' );
	        add_editor_style( get_theme_file_uri( 'css/style-editor.css' ) );

			// Add RSS feed links to <head> for posts and comments.
			add_theme_support( 'automatic-feed-links' );

			// Enable support for Post Thumbnails, and declare two sizes.
			add_theme_support( 'post-thumbnails' );

			// Enable Title Tag Support
			add_theme_support( "title-tag" );

			// Enable Custom Background feature
			add_theme_support( 'custom-background' );

			/*
			 * Make Theme available for translation.
			 */
			load_theme_textdomain( 'utouch-lite', get_template_directory() . '/languages' );

			set_post_thumbnail_size( 786, 450, true );

			/*
			 * Switch default core markup for search form, comment form, and comments
			 * to output valid HTML5.
			 */
			add_theme_support( 'html5', array(
				'search-form',
				'comment-form',
				'comments__list',
				'gallery',
				'caption',
				'script',
                'style'
			) );

			/*
			 * Enable support for Post Formats.
			 * See http://codex.wordpress.org/Post_Formats
			 */
			add_theme_support( 'post-formats', array(
				'video',
				'audio',
				'quote',
				'link',
				'gallery',
			) );


			// This theme uses its own gallery styles.
			add_filter( 'use_default_gallery_style', '__return_false' );

			// Declare 3-rd party plugins support
			add_theme_support( 'woocommerce', array(
				'product_grid' => array(
					'default_rows'    => 3,
					'min_rows'        => 2,
					'max_rows'        => 8,
					'default_columns' => 3,
					'min_columns'     => 2,
					'max_columns'     => 5,
				),
			) );
			add_theme_support( 'wc-product-gallery-zoom' );
			add_theme_support( 'wc-product-gallery-lightbox' );
			add_theme_support( 'wc-product-gallery-slider' );

			// Add image sizes
			add_image_size( 'utouch-avatar', 60, 60, true );
			add_image_size( 'utouch-standard', 800, 450, true );
			add_image_size( 'utouch-standard-full', 1200, 450, true );
			add_image_size( 'utouch-gallery', 800, 430, true );
		}

	}
endif;

add_action( 'after_setup_theme', '_action_utouch_setup' );

/**
 * Extend the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Presence of header image.
 * 3. Index views.
 * 4. Full-width content layout.
 * 5. Presence of footer widgets.
 * 6. Single views.
 *
 * @param array $classes A list of existing body class values.
 *
 * @return array The filtered body class list.
 * @internal
 */
function _filter_utouch_body_classes( $classes ) {
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	if ( is_archive() || is_search() || is_home() ) {
		$classes[] = 'list-view';
	}

	if ( is_active_sidebar( 'sidebar-footer' ) ) {
		$classes[] = 'footer-widgets';
	}

	if ( is_singular() && ! is_front_page() ) {
		$classes[] = 'singular';
	}

	$classes[] = 'crumina-grid';
	$classes[] = 'utouch-lite';

	return $classes;
}

add_filter( 'body_class', '_filter_utouch_body_classes' );

/**
 * Extend the default WordPress post classes.
 *
 * Adds a post class to denote:
 * Non-password protected page with a post thumbnail.
 *
 * @param array $classes A list of existing post class values.
 *
 * @return array The filtered post class list.
 * @internal
 */
function _filter_utouch_post_classes( $classes ) {
	if ( ! post_password_required() && ! is_attachment() && has_post_thumbnail() ) {
		$classes[] = 'has-post-thumbnail';
	}

	$is_boxed = 'no';
	if ( function_exists( 'fw_get_db_customizer_option' ) ) {
		$boxed    = fw_get_db_customizer_option( 'boxed_container', array() );
		$is_boxed = utouch_akg( 'show', $boxed, 'no' );
	}

	if ( $is_boxed === 'yes' ) {
		$classes[] = 'is-boxed';
	}

	return $classes;
}

add_filter( 'post_class', '_filter_utouch_post_classes' );

/**
 * Register widget areas.
 * @internal
 */
function _action_utouch_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Main Widget Area', 'utouch-lite' ),
		'id'            => 'sidebar-main',
		'description'   => esc_html__( 'Appears in the right section of the site.', 'utouch-lite' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area', 'utouch-lite' ),
		'id'            => 'sidebar-footer',
		'description'   => esc_html__( 'Appears in footer section. Every widget in own column ', 'utouch-lite' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s columns_class_replace">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );
}

add_action( 'widgets_init', '_action_utouch_widgets_init' );

/**
 * Count Widgets
 * Count the number of widgets to add dynamic column class
 *
 * @param string $sidebar_id id of sidebar
 *
 * @since 1.0.0
 *
 * @return int
 */
function utouch_get_widget_columns( $sidebar_id ) {
	// Default number of columns in grid is 12
	$columns = apply_filters( 'utouch_columns', 12 );

	// get the sidebar widgets
	$the_sidebars = wp_get_sidebars_widgets();

	// if sidebar doesn't exist return error
	if ( ! isset( $the_sidebars[ $sidebar_id ] ) ) {
		return esc_html__( 'Invalid sidebar ID', 'utouch-lite' );
	}

	/* count number of widgets in the sidebar
	  and do some simple math to calculate the columns */
	$num = count( $the_sidebars[ $sidebar_id ] );

	switch ( $num ) {
		case 1 :
			$num = $columns;
			break;
		case 2 :
			$num = $columns / 2;
			break;
		case 3 :
			$num = $columns / 3;
			break;
		case 4 :
			$num = $columns / 4;
			break;
		case 5 :
			$num = $columns / 5;
			break;
		case 6 :
			$num = $columns / 6;
			break;
		case 7 :
			$num = $columns / 7;
			break;
		case 8 :
			$num = $columns / 8;
			break;
	}
	$num = floor( $num );

	return $num;
}

/**
 * Custom read more Link formatting
 *
 * @return string
 */
function utouch_read_more_link() {
	return '';
}

add_filter( 'the_content_more_link', 'utouch_read_more_link' );

function utouch_excerpt_link( $output ) {
	return $output;
}

add_filter( 'get_the_excerpt', 'utouch_excerpt_link' );


/**
 * Customize the Password Form on Protected Posts
 *
 * @param int $post Post ID.
 *
 * @return string
 */
function utouch_password_form( $post ) {
	$current_post = get_post( $post );
	$label        = 'pwbox-' . ( empty( $current_post->ID ) ? rand() : $current_post->ID );
	$output       = '<h6>' . esc_html__( 'This content is password protected. To view it please enter your password below:', 'utouch-lite' ) . '</h6><form action="' . esc_url( home_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" class="post-password-form form-inline" method="post"><input name="post_password" required="required" id="' . $label . '" type="password" size="20"><button type="submit" name="Submit" class="btn btn--green">' . esc_attr__( 'Submit', 'utouch-lite' ) . '</button>
</form>';

	return $output;
}

add_filter( 'the_password_form', 'utouch_password_form' );


function utouch_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;

	return $fields;
}

add_filter( 'comment_form_fields', 'utouch_move_comment_field_to_bottom' );

/**
 * Change text strings
 *
 * @link http://codex.wordpress.org/Plugin_API/Filter_Reference/gettext
 */
function utouch_text_strings( $translated_text, $text, $domain ) {
	switch ( $translated_text ) {
		case 'Add Sidebar' :
			$translated_text = esc_html__( 'Save changes', 'utouch-lite' );
			break;
	}

	return $translated_text;
}

add_filter( 'gettext', 'utouch_text_strings', 20, 3 );

/**
 * Show specific Metabox for  page template.
 */
function utouch_disable_admin_metabox() {

	$only = array(
		'only' => array( array( 'id' => 'page' ) ),
	);
	if ( function_exists( 'fw_current_screen_match' ) && fw_current_screen_match( $only ) ) {
		$post_id = ( isset( $_GET['post'] ) ) ? $_GET['post'] : '';
		if ( empty( $post_id ) ) {
			remove_meta_box( 'fw-options-box-blog-page', 'page', 'normal' );
		}
		$template_file = get_post_meta( $post_id, '_wp_page_template', true );
		if ( 'blog-template.php' !== $template_file ) {
			remove_meta_box( 'fw-options-box-blog-page', 'page', 'normal' );
		}
	}
}

add_action( 'do_meta_boxes', 'utouch_disable_admin_metabox', 99 );

/**
 * Extend the default WordPress category title.
 *
 * Remove 'Category' word from cat title.
 *
 * @param string $title Original category title.
 *
 * @return string The filtered category title.
 * @internal
 */
function _filter_utouch_archive_title( $title ) {
	if ( is_home() ) {
		$title = esc_html__( 'Latest posts', 'utouch-lite' );
	} elseif ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( ( is_singular( 'post' ) ) ) {
		$category = get_the_category( get_the_ID() );
		$title    = $category[0]->name;
	} elseif ( is_singular( 'product' ) || is_singular( 'download' ) ) {
		$title = '<h2 class="stunning-header-title h1">' . esc_html__( 'Product Details', 'utouch-lite' ) . '</h2>';
	}

	return $title;
}

add_filter( 'get_the_archive_title', '_filter_utouch_archive_title' );



/**
 * add "btn reply" class to comment reply and edit links
 */
if ( ! function_exists( '_filter_utouch_edit_comment_link' ) ) {

	function _filter_utouch_edit_reply_comment_link( $link ) {

		$link = str_replace( 'comment-reply-link', 'comment-reply-link btn reply', $link );
		$link = str_replace( 'comment-edit-link', 'comment-edit-link btn reply', $link );
		$link = str_replace( 'respond', 'respond', $link );

		return $link;
	}

	add_filter( 'edit_comment_link', '_filter_utouch_edit_reply_comment_link', 10, 1 );
	add_filter( 'comment_reply_link', '_filter_utouch_edit_reply_comment_link', 10, 1 );
}

function utouch_gallery_style( $html ) {
	return str_replace( 'class=\'', 'class=\'gallery-popup ', $html );
}

add_filter( 'gallery_style', 'utouch_gallery_style' );


function utouch_filter_my_custom_breadcrumbs_items( $items ) {
	if ( 'front_page' === $items[0]['type'] && null === Utouch::get_var( 'breadcrumbs_show_homepage' ) ) {
		$items = array_slice( $items, 1 );
	}
	return $items;
}

add_filter( 'fw_ext_breadcrumbs_build', 'utouch_filter_my_custom_breadcrumbs_items' );


function utouch_post_class( $classes, $class, $post_id ) {
	// sticky for Sticky Posts
	if ( is_sticky( $post_id ) ) {
		if ( ! is_paged() ) {
			$classes[] = 'sticky';
		}
	}

	return $classes;
}

add_filter( 'post_class', 'utouch_post_class', 10, 3 );


function utouch_widget_nav_menu_args( $args ) {
	$args['utouch_footer_widget'] = true;
	$args['menu_class']           = 'menu list list--primary';

	return $args;
}

add_filter( 'widget_nav_menu_args', 'utouch_widget_nav_menu_args' );

function utouch_add_icon_to_menu( $html, $args ) {
	if ( ! array_key_exists( 'utouch_footer_widget', $args ) ) {
		return $html;
	}
	$html = str_replace( '</li>', '<svg class="utouch-icon utouch-icon-arrow-right"><use xlink:href="#utouch-icon-arrow-right"></use></svg></li>', $html );

	return $html;
}

add_filter( 'wp_nav_menu', 'utouch_add_icon_to_menu', 10, 2 );